/*

  constants for the blockinvert programs

  $Id: blockinvert.h,v 1.12 2004/10/05 01:10:04 becker Exp $


*/


#define BLOCK_NBASE 3			/* basic sub-col entries for A */
#define BLOCK_DIM 2			/* dimensions for solution,
					   in plane x-y as well as fault-local
					   where it's strike and normal 
					*/
/* 
   projection to use for fault local computations

   project_azi is basically the only one that works properly

*/
//#define FLT_ROT_PROJECTION PROJECT_AZI
#define FLT_ROT_PROJECTION OMERC_AZI

/* maximum number of blocks */
#define MAX_NR_BLOCK 20

/* 

this factor will ensure that omega Euler vectors for

 vel = omega \cross r 

 will be in deg/Myr if the input velocities are in mm/yr 
 and r is normalized to unity length

 gfac = 111.194926644559
*/
#define BLOCK_GFAC (RADIUS_EARTH/180.0*PI)

/* for assign_additional_sol_values, modes for assignment */
#define INIT_ADD_SOL 0
#define RANDOM_ADD_SOL 1
/* 
   filenames 
*/
/* input */
#define GPS_VEL_FILE "velc.data" /* GPS data */
#define FLTBLOCK_FILE "flt.block" /* geometry file */
#define STRESSDATA_FILE "stress.data" /* stress data */
#define STRESSDEPTH_FILE "stress.depth"	/* depth for stress eval for 
					   each point */
#define RIGIDBLOCKSITES_FILE "rsites.dat" /* file for the sites which 
					     are used to define a reference 
					     block */
/* output */
#define VELFITOUT_FILE "vel.fit" /* predicted velocities */
#define SLIPOUT_FILE "slip.fit" /* slip rates */
#define SOLOUT_FILE "solution.bin"
#define OMEGA_OUT "omega.dat"	/* solution vector and uncertainties in ASCII */
#define SFITOUT_FILE "stress.fit" /* predicted stresses */
#define SCSTRESSOUT_FILE "stress.dsca" /* scaled input (data) stresses */
#define FGEOOUT_FILE "fgeo.gmt" 	/* fault geometry for testing */
#define LDOUT_FILE "ld.fit"	/* locking depths */
#define CFACOUT_FILE "cfac.fit" /* coupling factors */
#define COVOUT_FILE "cov.asc"	/* covariance */
#define VELCOR_FILE "vcorr.dat"	/* velocities corrected for net
				   rotation */
#define VEL_GR_FILE "vsub.dat" /* net rotation used for correction */
#define EULER_POLE_FILE "epc.dat" /* file with euler poles
				     to constrain
				  */
#define SV_FILE "sv.dat"	/* singular value output */
#define CSD_FILE "csd.dat"	/* constraints on fault slip motion */
#define BLOCK_CENTROID_FILE "centroids.dat"

/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

