#include "interact.h"

/*
  reads in geometry file and calculates the interaction
  matrix 
  $Id: calc_interaction_matrix.c,v 1.8 2003/03/02 01:37:41 becker Exp $
*/
#define FULL_IMAT_MODE 1
#define RED_IMAT_MODE 2
void print_help_local(char *);

int main(int argc, char **argv)
{
  struct med *medium;
  struct flt *fault;
  int mode=0,i;
  if(argc<2)
    print_help_local(argv[0]);
  for(i=2;i<argc;i++){
    if(strcmp(argv[i],"-h")==0 || strcmp(argv[i],"-?")==0){
      print_help_local(argv[0]);
    }else if(strcmp(argv[i],"-r")==0){
      mode=RED_IMAT_MODE;
    }else{
      fprintf(stderr,"%s: can not use parameter %s, use -h for help page\n",
	      argv[0],argv[i]);
      exit(-1);
    }}
  read_geometry(argv[1],&medium,&fault,TRUE,FALSE,FALSE,FALSE);
  medium->i_mat_cutoff=I_MAT_CUTOFF_DEF;
  calc_interaction_matrix(medium,fault,TRUE);
  switch(mode){
  case FULL_IMAT_MODE:{
    if(!medium->read_int_mat_from_file)
      print_interaction_matrix(medium,fault);
    break;
  }
  case RED_IMAT_MODE:{
    print_reduced_interaction_matrix(medium,fault);
    break;
  }}
  exit(0);
}
void print_help_local(char *filename)
{ 
  fprintf(stderr,"%s file.patch\n",filename);
  fprintf(stderr,"%s: computes the interaction matrix based on fault patches in file.patch\n",
	  filename);
  fprintf(stderr,"%s: these are in the same format as in the \"%s\" file\n",
	  filename,GEOMETRY_FILE);
  fprintf(stderr,"%s: options:\n",filename);
  fprintf(stderr,"%s: -r   computes reduced interaction matrix\n",filename);
  exit(-1);
}

/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

