#include "interact.h"

/*

  reads in patch file and checks for positive 
  feedback between individual patches
  $Id: check_feedback.c,v 1.13 2003/03/02 01:37:41 becker Exp $

*/

int main(int argc,char **argv)
{
  struct med *medium;
  struct flt *fault;
  int evil_pair[2];
  my_boolean bailout=TRUE;
  switch(argc){
  case 2:{
    break;
  }
  case 3:{
    sscanf(argv[1],"%i",evil_pair);
    if(evil_pair[0]==0)
      bailout=FALSE;
    break;
  }
  default:{
    fprintf(stderr,"%s file.patch [0/1]\n\treads file.patch file in patch format (like %s)\n\tand checks for positive feedback patches\n",
	    argv[0],GEOMETRY_FILE);
    fprintf(stderr,"\tie., pairs of patches whose self-interaction is smaller than the cross triggering\n");
    fprintf(stderr,"\tif the second argument is set to zero, then program checks all patches\n");
    fprintf(stderr,"\tif it is 1, program will stop at first fatal pair (this is the default\n");
    exit(-1);
  }}
  // read in fault geometry and friction properties
  read_geometry(argv[1],&medium,&fault,TRUE,FALSE,FALSE,FALSE);
  // check all interactions
  if(!check_coulomb_stress_feedback(medium->nrflt,0,
				    fault,medium, TRUE,
				    CALC_I_COEFF_NOW,bailout,
				    evil_pair,-1.0))
    fprintf(stderr,"%s: could not find fatal interactions\n",argv[0]);
  else
    fprintf(stderr,"%s: found at least one fatal interaction\n",argv[0]);
  exit(0);
}

/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

