#include "interact.h"
/* 


check if two 3-D fault segments are far enough from each other 

leeway is the fraction distance at the edges, 
set to unity for no increased size


$Id: far_enough.c,v 1.6 2005/10/26 01:46:31 becker Exp $

 */
//#define SUPER_DEBUG

my_boolean far_enough(struct flt *fault1,struct flt *fault2,
		   COMP_PRECISION leeway)
{
  my_boolean outcome;
  COMP_PRECISION corner[4][3];
  float a[3],b[3],c[3],d[3],e[3],f[3],g[3],h[3];
  COMP_PRECISION corner2[4][3];
  int i,hit=0;

  calculate_bloated_corners(corner,fault1,leeway);
  calculate_bloated_corners(corner2,fault2,leeway);
  for(i=0;i<3;i++){
    a[i]=corner[0][i];b[i]=corner[1][i];
    c[i]=corner[2][i];d[i]=corner[3][i];
    e[i]=corner2[0][i];f[i]=corner2[1][i];
    g[i]=corner2[2][i];h[i]=corner2[3][i];
  }
  // use four fast triangle tests (slow, but ...)
  hit += tri_tri_intersect(a,b,d,e,f,h);
  hit += tri_tri_intersect(a,b,d,f,g,h);
  hit += tri_tri_intersect(b,c,d,e,f,h);
  hit += tri_tri_intersect(b,c,d,f,g,h);
  if(hit)
    outcome=FALSE;
  else
    outcome=TRUE;
  return(outcome);
}

/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

