/* 
   FILENAMES AND OUTPUT OPTIONS 
*/
#define GEOMETRY_FILE "geom.in" // patch geometry input
#define BC_FILE "bc.in" // boundary conditions
#define FAULT_PROP_FILE "fp.in" // fault properties
#define FAULT_STRESS_INIT_FILE "fsi.in" // stress initialization for faults
#define STRESS_OUT_FILE "stress.out" // stress field output
#define STRESS_HDR_FILE "stress.hdr" // header file
#define FAULT_STRESS_OUT_FILE "flt_stress.out" // stress on fault output
#define DISP_OUT_FILE "disp.out" // displacement field output
#define DISP_HDR_FILE "disp.hdr" // header 
#define FAULT_DATA_PREFIX "flt"
#define ONE_STEP_FAULT_DATA_FILE "flt.dat" // stress and displacement on fault data
#define EVENT_FILE_BINARY  "events.bin"    // binary event log for loading simulation
#define EVENT_FILE_ASCII  "events.dat"     // ASCII version
#define RESTART_EVENT_FILE_BINARY  "restart.events.bin" // restart file, where code looks for old EVENT_FILE_BINARY
#define RESTART_EVENT_FILE_ASCII  "restart.events.dat"  // same for ASCII
#define CEVENT_FILE "cevents.dat" // ASCII log of fault events (as opposed to patch events which are logged in EVENT_FILE_BINARY 
#define STRESS_STAT_FILE "sstat.dat" // stress heterogeneity statistics
#define OLOC_FILE "oloc.dat" // 
#define RES_STRESS_FILE "rstress.dat" // resolved stress on fault segments for one-step loading 
#define PLANE_COORD_FILE "plane.xyz" // file with real coordinates of fault plane local output

// program will atuomatically append the PID and ".dat" for the matrix
// and PID and ".hdr" for the header file
#define INTERACTION_MATRIX_FILE "/tmp/i"

#define A_MATRIX_FILE "a.dat"
#define A_CON_MATRIX_FILE "ac.dat"
#define DEBUG_A_CON_MATRIX_ASCII_OUT "ac.asc"
#define DEBUG_B_CON_VECTOR_ASCII_OUT "bc.asc"
#define DEBUG_X_CON_VECTOR_ASCII_OUT "xc.asc"
#define DEBUG_A_MIX_MATRIX_ASCII_OUT "am.asc"
#define DEBUG_B_MIX_VECTOR_ASCII_OUT "bm.asc"
#define DEBUG_X_MIX_VECTOR_ASCII_OUT "xm.asc"
#define SLIP_LINE_PREFIX "slipline"
#define STRESS_RELATION_FILE "smlin.in"

/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

