/*
  interact: model fault interactions using dislocations in a 
            halfspace
  (C) Thorsten Becker, becker@eps.harvard.edu

  $Id: fltcopy.c,v 2.7 2002/10/08 19:24:44 tbecker Exp $
*/
#include "interact.h"

void fltswap(struct flt *a, struct flt *b)
{
  struct flt c;
  fltcp(a,&c);
  fltcp(b,a);
  fltcp(&c,b);
}
//
// copy fault a to fault b
//
// b = a
//
void fltcp(struct flt *a, struct flt *b)
{
  int i;
  a_equals_b_vector_3d(b->u,a->u);
  a_equals_b_vector_3d(b->s,a->s);
  a_equals_b_vector_3d(b->sinc,a->sinc);
  a_equals_b_vector_3d(b->x,a->x);

#ifdef ALLOW_NON_3DQUAD_GEOM
  b->type = a->type;
  if(a->type == TRIANGULAR){
    a_equals_b_vector(b->xt,a->xt,9);
  }
#endif 
  for(i=0;i<2;i++){
    b->pos[i] = a->pos[i];
    b->cf[i] = a->cf[i];
  }
  b->l = a->l;
  b->w = a->w;
  b->area = a->area;

  b->strike = a->strike;
  b->dip = a->dip;

  b->sin_alpha = a->sin_alpha;
  b->cos_alpha = a->cos_alpha;

  a_equals_b_vector_3d(b->normal,a->normal);
  a_equals_b_vector_3d(b->t_strike,a->t_strike);
  a_equals_b_vector_3d(b->t_dip,a->t_dip);
  
  b->mu_d = a->mu_d;
  b->mu_s = a->mu_s;
  b->f_initial = a->f_initial;
  b->taud = a->taud;

#ifdef LATENCY
  b->last_activation_time = a->last_activation_time;
#endif
  
  b->group = a->group;
  b->active = a->active;

  for(i=0;i<3;i++)
    b->mode[i] = a->mode[i];
}

/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

