/*
  interact: model fault interactions using dislocations in a 
            halfspace
  (C) Thorsten Becker, becker@eps.harvard.edu

  $Id: mysincos.c,v 1.4 2002-12-14 16:43:25-08 becker Exp tbecker $

  uses SUN's sincos routines that are only available in double precision!?
*/
#include "interact.h"
#include <math.h>
#ifdef SUN_TRIG_FUNCTIONS
#include <sunmath.h>
#endif

/*  calculate sin and cos from an angle given in degrees */
void my_sincos_deg(COMP_PRECISION *sin_val,COMP_PRECISION *cos_val,
		   COMP_PRECISION alpha_in_degrees)
{
#if !defined(SUN_TRIG_FUNCTIONS) || !defined(USE_DOUBLE_PRECISION)
  COMP_PRECISION tmp;
  tmp = alpha_in_degrees * DEG2RAD;
  *sin_val = sin(tmp);
  *cos_val = cos(tmp);
#else
  // using double prec and sun libs
  sincosd(alpha_in_degrees, sin_val, cos_val);
#endif
}
// fortran version
void my_sincos_deg_ftn(COMP_PRECISION *sin_val,COMP_PRECISION *cos_val,
		       COMP_PRECISION *alpha_in_degrees)
{
#if !defined(SUN_TRIG_FUNCTIONS) || !defined(USE_DOUBLE_PRECISION)
  COMP_PRECISION tmp;
  tmp = *alpha_in_degrees * DEG2RAD;
  *sin_val = sin(tmp);
  *cos_val = cos(tmp);
#else
  // using double prec and sun libs
  sincosd(*alpha_in_degrees, sin_val, cos_val);
#endif
}

/*  calculate the sin and cos of arad, an angle in radians */
void my_sincos(COMP_PRECISION *sin_val,COMP_PRECISION *cos_val,
	       COMP_PRECISION arad)
{
#if !defined(SUN_TRIG_FUNCTIONS) || !defined(USE_DOUBLE_PRECISION)
  *sin_val = sin(arad);
  *cos_val = cos(arad);
#else
  sincos(arad,sin_val,cos_val);
#endif
}


/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

