#include "interact.h"
#include "properties.h"
//
// reads in patch format and writes geom format for geomview
//
/* 

this file can also produce colored slip COFF files using 
geom.in and a headerless flt.nohdr.dat file


 */

int main(int argc, char **argv)
{
  
  struct flt *fault;
  struct med *medium;
  double a[3];
  int i;
  FILE *in;
  my_boolean shrink_patches=FALSE,read_slip=FALSE;
  COMP_PRECISION fixed_range=0.025;
  char filename[2000];
  if(argc >= 2){
    sscanf(argv[1],"%i",&i);
    shrink_patches = (my_boolean)i;
  }
  if(argc == 3){
    sscanf(argv[2],"%i",&i);
    read_slip = (my_boolean)i;
  }
  if(argc > 3){
    fprintf(stderr,"%s [shrink_patches, 0] [read_slip, 0]\n\t reads in patch format from stdin and writes Geomview OFF format to stdout\n",
	    argv[0]);
    fprintf(stderr,"if shrink_patches is set, will make patches smaller for plotting\n");
    exit(-1);
  }
  fprintf(stderr,"%s: reading patch format from stdin, writing OFF to stdout. shrink: %i read_slip: %i\n",
	  argv[0],shrink_patches,read_slip);
  
  read_geometry("stdin",&medium,&fault,FALSE,FALSE,FALSE,FALSE);
  if(read_slip){
    fprintf(stderr,"%s: attemping to read slip values from flt.nohdr.dat\n",argv[0]);
    in=myopen("flt.nohdr.dat","r");
    for(i=0;i<medium->nrflt;i++){ /* read in slip values from headerless file */
      if(fscanf(in,"%*f %*f %*f %*f %*f %lf %lf %lf %*f %*f %*f %*i %*i",a,(a+1),(a+2))!=3){
	fault[i].u[STRIKE]=a[0];fault[i].u[DIP]=a[1];fault[i].u[NORMAL]=a[2];
	fprintf(stderr,"%s: read error file  flt.nohdr.dat, patch %i\n",
		argv[0],i+1);
	exit(-1);
      }
    }
    for(i=0;i<medium->nrgrp;i++){
      sprintf(filename,"flt.%i.abs.off",i);
      print_group_data_geom(filename,medium,fault,i,0,fixed_range);
      sprintf(filename,"flt.%i.strike.off",i);
      print_group_data_geom(filename,medium,fault,i,1,fixed_range);
      sprintf(filename,"flt.%i.dip.off",i);
      print_group_data_geom(filename,medium,fault,i,2,fixed_range);
    }
  }else{
    for(i=0;i<medium->nrflt;i++)
      print_patch_geometry_and_bc(0,(fault+i),GEOMVIEW_MODE,
				  0.0,TRUE,stdout,shrink_patches);
  }
  exit(0);
}


/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

