#include "interact.h"

/*
  reads in patch file and determines average quantities
  of the groups of faults that the patches form
  $Id: patch2group.c,v 1.9 2003/03/02 01:37:41 becker Exp $
*/

int main(int argc,char **argv)
{
  struct med *medium;
  struct flt *fault;
  struct geog *grp;
  int i;
  switch(argc){
  case 2:{
    break;
  }
  default:{
    fprintf(stderr,"%s file.patch\n",argv[0]);
    fprintf(stderr,"\treads file.patch file in patch format (like %s)\n\tand determines geometrical quantities of fault groups\n",
	    GEOMETRY_FILE);
    exit(-1);
  }}
  // read in patches
  read_geometry(argv[1],&medium,&fault,FALSE,FALSE,FALSE,FALSE);
  /* init group structs */
  if(!(grp=(struct geog *)calloc(medium->nrgrp,
				 sizeof(struct geog))))
    MEMERROR("main");
  // determine average geometrical quantities of the groups
  calc_group_geometry(medium,fault,grp);
  fprintf(stderr,"%s: writing geometry of groups of patches to stdout\n",argv[0]);
  // output in patch format 
  for(i=0;i<medium->nrgrp;i++)
    fprintf(stdout,"%g %g %g %g %g %g %g %i\n",
	    grp[i].center[X],grp[i].center[Y],grp[i].center[Z],
	    vec_to_strike(grp[i].strike_vec),vec_to_dip(grp[i].dip_vec),
	    grp[i].prange[STRIKE],grp[i].prange[DIP],i);

  exit(0);
}

/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

