#include "interact.h"

/*


  $Id: randomize_list.c,v 1.4 2003/02/13 22:45:12 becker Exp $

  generate a random list of integers list(0..N-1) with 
  that contains all integers from 0 to N - 1

  list will be initialized locally

  if randomize is false, list will be 0, 1, 2 ... N-1
  
*/
void randomize_list(int **list, int n, my_boolean randomize)
{
  struct slist *lists;
  int i;
  long int seed=-1;
  if(n<1){
    fprintf(stderr,"randomize_list: error: called with n: %i\n",n);
    exit(-1);
  }
  *list = (int *)malloc(sizeof(int)*n);
  if(! *list)
    MEMERROR("randomize_list");
  if(!randomize){
    for(i=0;i<n;i++)
      *(*list+i) = i;
    return;
  }else{
    lists = (struct slist *)malloc(sizeof(struct slist)*n);
    /*

      generate random permutation of list by assigning random numbers
      and sorting

    */
    if(!lists)
      MEMERROR("randomize_list");
    for(i=0;i<n;i++){
      lists[i].x = myrand(&seed);
      lists[i].i = i;
    }
    qsort(lists,n,sizeof(struct slist),slist_sort);
    for(i=0;i<n;i++)
      *(*list+i) = lists[i].i;
    free(lists);
  }
}

int slist_sort(const void *va, const void *vb)
{
  struct slist *a = (struct slist *) va, 
    *b = (struct slist *) vb;
  if(a->x < b->x)
    return -1;
  else if(a->x == b->x)
    return 0;
  else
    return 1;
}

/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

