#include "interact.h"

int main(void)
{
  COMP_PRECISION t,dt,tstop,aspect,tm,m,w,l,rm,
    lmin,lmax,wmin,sd,sdrange,sdmin,mmin,p,mmax,aspecth;
  long seed=-1;
  dt = 0.001;

  
  tstop = 100;
  
  aspect = 3.0;
  aspecth = aspect/2;
  
  /* min and max stress drop (or moment size) */
  sdmin = 1e-5;sdrange=1-sdmin;

  /* min patch size */
  lmin = aspect / 100.0;lmax=aspect-lmin;
  wmin = 1.0 / 100.0;

  /* smallest moment */
  mmin = wmin*wmin*lmin;
  /* largest moment */
  mmax = aspect;

  myrand(&seed);

  tm=rm=0.0;
  t=0.0;
  while(t < tstop){
    /* 
       test quake 
    */
    /* moment pre factor */
    //sd = sdmin + myrandnr(sdrange,&seed);
    sd = 0.5 + mygauss_randnr(1.0,&seed);
    if(sd < sdmin)sd = sdmin;
    if(sd > 1.0)sd = 1.0;
    /* max possible moment */
    m = (tm - rm) * sd;
    /* compute minimum probability */
    p =  m*m*dt*100000/sd;
    /* will earthquake happen? */
    if((m > mmin) && (myrand(&seed) > p)){
      w = 2.0;
      while((w > 1)||(w < wmin)){
	/* pick l */
	//l = lmin + myrandnr(lmax,&seed);
	l = aspecth + mygauss_randnr(aspect,&seed);
	if(l<lmin)l=lmin;
	if(l>aspect)l=aspect;
	w = sqrt(m/l);		/* compute w from m = w^2 l */
      }
      rm += m;
      printf("%12.5e %11g %11g %11g %11g %11g\n",t,l,w,m,rm,tm);
    }
    tm += dt;
    t += dt;
  }
  
  return 0;
}

/*

################################################################################
#                                                                              #
#  interact: model fault interactions using dislocations in an elastic         #
#            medium                                                            #
#	                                                                       #
#    Copyright (C) Thorsten W. Becker 2000 - 2002                              #
#                                                                              #
#    Unteract uses dc3d.f as provided by Y. Okada as in Okada (BSSA, 1992) and #
#    linear algebra routines from SLATEC, LAPACK, and EISPACK.                 #
#    Might contain material copyrighted by others (e.g. Numerical Recipes etc) #
#                                                                              #
#  If you use interact in real work, a citation to use would be:               #
#                                                                              #
#  @Article{becker02c,                                                         #
#    author = 	 {Becker, T. W. and Schott, B.},                               #
#    title = 	 {On boundary-element models of elastic fault interaction      #
#                  (abstract)},                                                # 
#    journal = 	 {EOS Trans. AGU},                                             #
#    year = 	 2002,                                                         #
#    volume =	 83,                                                           #
#    number =	 47,                                                           #
#    pages =	 {NG62A-0925}                                                  #
#  }                                                                           #
#                                                                              #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#    In addition, we strongly suggest that iGMT users comply with the goals    #
#    as expressed in the Student Pugwash Pledge (www.spusa.org/pugwash/).      #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

*/

